rm(list = ls())
library(glmnet)
library(xrnet)
library(doParallel)
library(dplyr)
library(xtune)
library(randomForest)
library(fwelnet)

# Make sure working directory is ".../JDS2107-007/"
getwd()

# Get data
methyl <- readRDS(file = paste0("RDA/Data/Methyl/methyl.RDS"))
methyl_gene <- readRDS(file = paste0("RDA/Data/Methyl/methyl_gene.RDS"))
ext_data <- readRDS(file = paste0("RDA/Data/Methyl/ext_data.RDS"))
y <- readRDS(file = paste0("RDA/Data/Methyl/y.RDS"))


# Training and testing set splits
foldId <- readRDS(file = paste0("RDA/Methyl/train_test_folds10.rds"))

numProbes <- colSums(ext_data)
ext_data <- t(t(ext_data) / numProbes)

#-----
# Cycle and save all 50 folds

sim <- 1 # Change this manually 1 to 50

# 12 cores available
nCores <- 12

myControl <- xrnet.control(tolerance = 1e-06)
penMain <- define_penalty(0, num_penalty = 20, penalty_ratio = 0.00001)
penExt <- define_penalty(0, num_penalty = 20, penalty_ratio = 0.00001)


simParams <- foldId[[sim]]

y.train <- y[simParams$train]
y.test <- y[simParams$test]
X.train <- methyl[simParams$train, ]
X.test <- methyl[simParams$test, ]


length(y.train)
length(y.test)


#----- Run LASSO-Ridge

registerDoParallel(nCores)
fit_ridge_ridge <- tune_xrnet(x = X.train,
                              y = y.train,
                              external = ext_data,
                              # Main penalty
                              penalty_main = penMain,
                              # Second-order penalty
                              penalty_ext = penExt,
                              intercept = c(TRUE, FALSE),
                              standardize = c(TRUE, FALSE),
                              parallel = TRUE, nfolds = 10,
                              control = myControl,
                              foldid = simParams$foldid)
stopImplicitCluster()

rr_pred <- predict(fit_ridge_ridge, newdata = X.test)
rr_pmse <- mean((y.test - rr_pred)^2)
rr_r2   <- 1 - sum((y.test - rr_pred)^2) / sum((y.test - mean(y.test))^2)

#----- Run GLMNET
registerDoParallel(nCores)
fit_glmnet_ridge <- cv.glmnet(X.train, 
                        y.train, nlambda = 20,
                        alpha = 0,
                        parallel = TRUE, nfolds = 10,
                        foldid = simParams$foldid)
stopImplicitCluster()

glm_pred <- predict(fit_glmnet_ridge, newx = X.test, 
                    s = "lambda.min")
glm_pmse <- mean((y.test - glm_pred)^2)
glm_r2   <- 1 - sum((y.test - glm_pred)^2) / sum((y.test - mean(y.test))^2)

registerDoParallel(nCores)
fit_glmnet_ridge2 <- cv.glmnet(cbind(X.train, X.train %*% ext_data), 
                        y.train, nlambda = 20, 
                        alpha = 0,
                        parallel = TRUE, nfolds = 10,
                        foldid = simParams$foldid)

stopImplicitCluster()

aug_coef <- as.vector(coef(fit_glmnet_ridge2))
aug_pred <- predict(fit_glmnet_ridge2, newx = cbind(X.test, X.test %*% ext_data), 
                    s = "lambda.min")
aug_pmse <- mean((y.test - aug_pred)^2)
aug_r2   <- 1 - sum((y.test - aug_pred)^2) / sum((y.test - mean(y.test))^2)

aug_pred <- predict(fit_glmnet_ridge2, newx = cbind(X.test, matrix(0, nrow = dim(X.test)[1], ncol = dim(ext_data)[2])),
                    s = "lambda.min")
aug2_pmse <- mean((y.test - aug_pred)^2)
aug2_r2   <- 1 - sum((y.test - aug_pred)^2) / sum((y.test - mean(y.test))^2)

#########################################
# Clean up
#########################################
save(
  rr_pmse, rr_r2, glm_pmse, glm_r2,
  aug_pmse, aug_r2, aug2_pmse, aug2_r2,
  file = paste0("RDA/Methyl/results/analysis_w_avgext", sim, ".RData"))
