generateOutcomes <- function(nsub = 100, ncovs = 200, alpha, alpha_intercept = 0, beta_intercept = 0,
                             Z, X, SNR.beta, SNR.y, R2.y, sigmaY) {
  
  # NOTE: Make sure createCorrelationStructure is loaded into environment
  
  nxinf = length(alpha) # q: External information dimension (possible HD)
  
  ############################
 
  # 1) Generate covariate information signal and design matrix
  Z <- cbind(1, Z); alpha <- c(alpha_intercept, alpha)
  
  sigma.beta <- sqrt((t(alpha) %*% var(Z) %*% alpha) / SNR.beta) #Get sd for beta based on SNR
  beta0 <- rnorm(ncovs, mean = Z %*% alpha, sd = sigma.beta)
  
  # 2) Generate outcome based on X and beta0
  y <- rnorm(nsub, mean = X %*% beta0 + beta_intercept, sd = sigmaY)
  
  return(list(
    y = y,
    X = X,
    Z = Z[, -1],
    beta = beta0,
    alpha = alpha[-1])
  )
}

## Example:
#alpha <- rnorm(50)
#alpha <- ifelse(abs(alpha) > 1.0, round(alpha, 2), 0)
#out <- generateSimulationData(nsub = 100, ncovs = 200, alpha = alpha, sigmaX = 0.5, sigmaY = 1.0,
#                              covZ = "ar", covX = "ar", rhoZ = 0.5, rhoX = 0.5, isBinaryZ = TRUE,
#                              isBinaryX = FALSE, propZ = 0.5, propX = 0.5)
