generateSimulationData <- function(nsub = 100, ncovs = 200, alpha, alpha_intercept = 0, beta_intercept = 0, 
                                   SNR.beta, SNR.y, R2.y, sigmaY,
                                   covZ = "cs", covX = "ar", rhoZ = rho1, rhoX = rho2,
                                   isBinaryZ = FALSE, isBinaryX = FALSE, propZ = 0.3, propX = 0.3) {

  # NOTE: Make sure createCorrelationStructure is loaded into environment

  nxinf = length(alpha) # q: External information dimension (possible HD)

  ############################
  # 1) Generate external information design matrix via a multivariate normal
  V <- createCorrelationStructure(nxinf, method = covZ, rho = rhoZ)
  Z <- matrix(rnorm(ncovs * nxinf), nrow = ncovs)
  Z <- Z %*% chol(V) # Transforms design matrix to have correlation defined by V

  # If Z is binary
  if (isBinaryZ) {
    Z <- ifelse(abs(Z) > qnorm(1 - propZ / 2), 1, 0)
  }

  ############################
  # 2) Generate covariate information signal and design matrix
  Z <- cbind(1, Z); alpha <- c(alpha_intercept, alpha)

  sigma.beta <- sqrt((t(alpha) %*% var(Z) %*% alpha) / SNR.beta) #Get sd for beta based on SNR
  beta0 <- rnorm(ncovs, mean = Z %*% alpha, sd = sigma.beta)


  V <- createCorrelationStructure(ncovs, method = covX, rho = rhoX)
  X <- matrix(rnorm(nsub * ncovs), nrow = nsub)
  X <- X %*% chol(V) # Transforms design matrix to have correlation defined by V

  if (isBinaryX) {
    X <- ifelse(abs(X) > qnorm(1 - propX / 2), 1, 0)
  }

  ############################
  # 3) Generate outcome based on X and beta0
  #sigmaY <- sqrt(R2.y / (ncovs * SNR.y))
  y <- rnorm(nsub, mean = X %*% beta0 + beta_intercept, sd = sigmaY)

  return(list(
    y = y,
    X = X,
    Z = Z[, -1],
    beta = beta0,
    alpha = alpha[-1])
  )
}

## Example:
#alpha <- rnorm(50)
#alpha <- ifelse(abs(alpha) > 1.0, round(alpha, 2), 0)
#out <- generateSimulationData(nsub = 100, ncovs = 200, alpha = alpha, sigmaX = 0.5, sigmaY = 1.0,
#                              covZ = "ar", covX = "ar", rhoZ = 0.5, rhoX = 0.5, isBinaryZ = TRUE,
#                              isBinaryX = FALSE, propZ = 0.5, propX = 0.5)
